# Python Markdown Extensions

## Reference

- [Extension API](https://python-markdown.github.io/extensions/api/)

## Feature

| feature |   input    |  output   |
|:-------:|:----------:|:---------:|
|   del   | \~~trike~~ | ~~trike~~ |
